==> deepin-home_1.6.0.tar.xz: BUILD/translations/deepin-home/sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unlogged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Së afërmi</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Newest</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Komunikim</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Diskutoni dhe ndani ide me të tjerë këtu</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Njoftim të Metash</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Njoftoni probleme që gjetët</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugjerime</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Parashtroni sugjerimet tuaja</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Burime</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Pyetësor</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Bëhuni Pjesë e Jona</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Testim i Brendshëm</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Lajme Nga Bashkësi</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>Messages</source>
        <translation>Mesazhe</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Pyetësorë</translation>
    </message>
    <message>
        <source>No more items</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Nise gjatë nisjes së sistemit</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Mbi</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dalje</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Kreu Deepin</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Ende pa mesazhe.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 mesazhe</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Vëru të tërëve shenjë si të lexuar</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Shihni më tepër</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Kreu Deepin</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Ende pa pyetësorë.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Ka skaduar më: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Plotësojeni</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Replied</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Resolved</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Evaluating</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Accepted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reproducing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug Report</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Title：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Content：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Email：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device Info：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device Information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Urged</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-home_1.6.3.tar.xz: BUILD/translations/deepin-home/sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Ju lutemi, bëni hyrjen me ID-në tuaj Deepin.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Që të vazhdohet me veprimet pausese, lypset të bëni hyrjen.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Keni bërë shumë kërkesa, ju lutemi, riprovoni më vonë.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Që të vazhdohet me veprimet pausese, lypset të bëni hyrjen.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Gabim rrjeti, ju lutemi, provoni më vonë</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>I pafutur</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Të parapëlqyerit e Mi</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Përshtypjet e Mia</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Dilni</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Hyni</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 parje</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugjerime</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe nga të parapëlqyerit</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Vëri shenjë si të parapëlqyer</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>S’afërmi</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Përgjigje zyrtare</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Lloj:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Krejt</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>E metë</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugjerime</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Renditi:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Më të rejat</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Komunikim</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Diskutoni dhe ndani ide me të tjerë këtu</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Njoftim të Metash</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Njoftoni probleme që gjetët</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugjerime</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Parashtroni sugjerimet tuaja</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Burime</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Pyetësor</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Bëhuni Pjesë e Jona</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Testim i Brendshëm</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Community News</source>
        <translation>Lajme Nga Bashkësia</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>S’ka më objekte</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Mesazhe</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Pyetësorë</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Nise gjatë nisjes së sistemit</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Mbi</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dalje</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Kreu Deepin</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Hyni shpejt në forume, parashtroni sugjerime dhe njoftoni të meta.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Ende pa mesazhe.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 mesazhe</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Vëru të tërëve shenjë si të lexuar</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Shihni më tepër</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Gabim rrjeti, ju lutemi, provoni më vonë</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rifreskoje</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Kreu Deepin</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Ende pa pyetësorë.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Ka skaduar më: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Plotësojeni</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Pezull</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Riprodhim</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>I ripohuar</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Me përgjigje</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>E zgjidhur</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Po vlerësohet</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>E pranuar</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>E plotësuar</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Çështja s’është përpunuar dhe s’do të shfaqet në lista publike.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Aktualisht jo në gjendje të identifikohet shkaku, lypset mbikëqyrje dhe hetim i vazhdueshëm.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>Çështja është riprodhuar dhe është identifikuar shkaku bazë.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>Çështja s’është ndonjë e metë apo e një natyre tjetër.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>Çështja është zgjidhur dhe është në pritje të hedhjes formale në qarkullim</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Domosdoshmëria s’është përpunuar dhe s’do të shfaqet në lista publike.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Çështja është pranuar dhe po vlerësohet së brendshmi</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Përfshirë në plane për hedhje të ardhshme në qarkullim</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Domosdoshmëria ose s’është pranuar, ose s’janë në gjendje ta trajtojnë</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Puna për zhvillim ka përfunduar, po pritet për hedhje formale në qarkullim</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>S’arrihet të shtohet foto ekrani.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>Madhësia e kartelës figurë duhet të jetë më pak se 1MB.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Formati i kartelës figurë s’mbulohet për ngarkime.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Gjendje e Tanishme e Produktit]: 
[Produkt i Dëshiruar]: </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Parakushte]: 
[Hapa Riprodhimi]: 
[Përfundime të Pritura]: 
[Përfundime Faktike]: </translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Parashtroni Përshtypje</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Lloj:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugjerime</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Njoftim të Metash</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Titull：</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Ju lutemi, jepni një përshkrim të shkurtër të problemit tuaj</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Lëndë</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Mos plotësoni domosdoshmëri të shumta brenda një përshtypjeje</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Mos plotësoni domosdoshmëri të shumta brenda një përshtypjeje</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>Email：</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Ju lutemi, jepni email-in tuaj</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Version Sistemi:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Hollësi Pajisjeje:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Ngarkoni &lt;a href=&apos;home://sysinfo&apos;&gt;hollësi pajisjeje&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Foto ekrani:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Kartela figurash</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Merrni dhe hidhni kartela, ose klikoni butona për shtim deri në tre fotografish</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Jeni i sigurt se doni të braktisni dhënien e përshtypjeve?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Lënda e përshtypjes s’do të ruhet.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dil</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Parashtroje</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>S’arrihet të parashtrohen përshtypjet</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Ju lutemi, jepni titullin dhe lëndën e përshtypjeve tuaja.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Ju lutemi, jepni titullin për përshtypjet tuaja.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Ju lutemi, jepni lëndën e përshtypjeve tuaja.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>U dha adresë email e pasaktë.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Hollësi Pajisjeje</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Qendër Përshtypjesh</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Përshtypjet e Mia</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Të parapëlqyerit e Mi</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
